PyPette Admin
=============


Adds /admin urls to your app.

It does that by loading admin templates and models
(currently only peewee supported).


You can register a model by doing `register_model(model)`,
this will add `/admin/model` to your app.
